#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11
visibility:           public
id:                   ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i
key:                  ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/feuerbach/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  b821b589aa350230d74c42913e6cd062
exposed:              True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ansi-terminal-0.11
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ansi-terminal-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/ansi-terminal-0.11
hs-libraries:         HSansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i
depends:              base-4.14.2.0 colour-2.3.5-Kcgb8k1EndZEaiZNG4e3mM
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

